// Buczko Tamas
// ThreadTest 2006
// Siemens PSE
package threadmark;

import test.prime.PrimeFarmer;
import test.multiple.MultipleFarmer;
import java.awt.Dimension;
import java.awt.Toolkit;
import java.net.URL;
import java.util.Date;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JFrame;
import test.code.CodeFarmer;

public class GUI extends JFrame {
    
    private Icon icGreen = getIcon("green.gif");
    private Icon icRed = getIcon("red.gif");
    private Icon icGrey = getIcon("grey.gif");
    
    private IFarmer myFarmer;
    
    private long maxRunTime;
    private long minRunTime;
    private long lastRunTime;
    private long maxOp;
    private long minOp;
    private long lastOp;
    private long maxRead;
    private long minRead;
    private long lastRead;
    private long maxWrite;
    private long minWrite;
    private long lastWrite;
    
    public GUI() {
        initComponents();
        Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        setBounds((screenSize.width-655)/2, (screenSize.height-375)/2, 655, 375);
    }
    
    public Icon getIcon(String imgName) {
        URL imgURL = getClass().getResource("/threadmark/" + imgName);
        return imgURL == null ? null : new ImageIcon(imgURL);
    }
    
    private void reset() {
        maxRunTime = Long.MIN_VALUE;
        minRunTime = Long.MAX_VALUE;
        lastRunTime = Long.MIN_VALUE;;
        maxOp = Long.MIN_VALUE;
        minOp = Long.MAX_VALUE;
        lastOp = Long.MAX_VALUE;
        maxRead = Long.MIN_VALUE;
        minRead = Long.MAX_VALUE;
        lastRead = Long.MAX_VALUE;
        maxWrite = Long.MIN_VALUE;
        minWrite = Long.MAX_VALUE;
        lastWrite = Long.MAX_VALUE;
    }
    
    // Adatok megjelenitese
    private void print(int threadCount, long runTimeMilliSec, long cpuOp, long ioRead, long ioWrite) {
        
        String tcSuffix = " [" + Integer.toString(threadCount) + "]";
        
        prbThreadCount.setValue(threadCount);
        lblThreadCount.setText("Thread Count: " + threadCount);
        lblRunTimeSec.setText("Run Time: " + Long.toString(runTimeMilliSec) + " ms");
        lblOperation.setText("Operation: " + Long.toString(cpuOp) + " opms");
        lblRead.setText("Read: " + Long.toString(ioRead) + " bpms");
        lblWrite.setText("Write: " + Long.toString(ioWrite) + " bpms");
        
        if(lastRunTime == runTimeMilliSec) {
            lblRunTimeSec.setIcon(icGrey);
        } else if(lastRunTime < runTimeMilliSec) {
            lblRunTimeSec.setIcon(icRed);
        } else if(lastRunTime > runTimeMilliSec) {
            lblRunTimeSec.setIcon(icGreen);
        }
        lastRunTime = runTimeMilliSec;
        
        if(runTimeMilliSec < minRunTime) {
            lblMinRunTimeSecView.setText(Long.toString(runTimeMilliSec) +  " ms" + tcSuffix);
            minRunTime = runTimeMilliSec;
            prbRunTimeSec.setValue((int) runTimeMilliSec);
        } else if(runTimeMilliSec > maxRunTime) {
            lblMaxRunTimeSecView.setText(Long.toString(runTimeMilliSec) +  " ms" + tcSuffix);
            maxRunTime = runTimeMilliSec;
            prbRunTimeSec.setMaximum((int) runTimeMilliSec);
            prbRunTimeSec.setValue((int) runTimeMilliSec);
        }
        
        if(lastOp == cpuOp) {
            lblOperation.setIcon(icGrey);
        } else if(lastOp > cpuOp) {
            lblOperation.setIcon(icRed);
        } else if(lastOp < cpuOp) {
            lblOperation.setIcon(icGreen);
        }
        lastOp = cpuOp;
        
        if(cpuOp < minOp) {
            lblMinOperationView.setText(Long.toString(cpuOp) + " opms" + tcSuffix);
            minOp = cpuOp;
            prbOperation.setValue((int)cpuOp);
        } else if(cpuOp > maxOp) {
            lblMaxOperationView.setText(Long.toString(cpuOp) + " opms" + tcSuffix);
            maxOp = cpuOp;
            prbOperation.setMaximum((int)cpuOp);
            prbOperation.setValue((int)cpuOp);
        }
        
        if(lastRead == ioRead) {
            lblRead.setIcon(icGrey);
        } else if(lastRead > ioRead) {
            lblRead.setIcon(icRed);
        } else if(lastRead < ioRead) {
            lblRead.setIcon(icGreen);
        }
        lastRead = ioRead;
        
        if(ioRead < minRead) {
            lblMinIOReadView.setText(Long.toString(ioRead) + " kbpms" + tcSuffix);
            minRead = ioRead;
            prbRead.setValue((int)ioRead);
        } else if(ioRead > maxRead) {
            lblMaxIOReadView.setText(Long.toString(ioRead) + " kbpms" + tcSuffix);
            maxRead = ioRead;
            prbRead.setMaximum((int)ioRead);
            prbRead.setValue((int)ioRead);
        }
        
        if(lastWrite == ioWrite) {
            lblWrite.setIcon(icGrey);
        } else if(lastWrite > ioWrite) {
            lblWrite.setIcon(icRed);
        } else if(lastWrite < ioWrite) {
            lblWrite.setIcon(icGreen);
        }
        lastWrite = ioWrite;
        
        if(ioWrite < minWrite) {
            lblMinIOWriteView.setText(Long.toString(ioWrite) + " bpms" + tcSuffix);
            minWrite = ioWrite;
            prbWrite.setValue((int)ioWrite);
        } else if(ioWrite > maxWrite) {
            lblMaxIOWriteView.setText(Long.toString(ioWrite) + " bpms" + tcSuffix);
            maxWrite = ioWrite;
            prbWrite.setMaximum((int)ioWrite);
            prbWrite.setValue((int)ioWrite);
        }
        
        update(getGraphics());
    }
    
    
    private void start(String tester) {
        reset();
        
        int minThreadCount = Integer.parseInt(txtMinThreadCount.getText());
        int maxThreadCount = Integer.parseInt(txtMaxThreadCount.getText());
        int increment = Integer.parseInt(txtIncrement.getText());
        
        prbThreadCount.setMaximum(maxThreadCount);
        
        for(int wCount = minThreadCount; wCount <= maxThreadCount; wCount += increment) {
            
            long startTime = new Date().getTime();
            
            if(tester.equals("Find Primes (CPU)")) {
                myFarmer = new PrimeFarmer();
            } else if(tester.equals("Multiple File (I/O)")) {
                myFarmer = new MultipleFarmer();
            }else if(tester.equals("Code File (CPU & I/O)")) {
                myFarmer = new CodeFarmer();
            }
            
            if(chbGarbageCollector.isSelected()) {
                System.gc();
            }
            
            myFarmer.doWork(wCount);
            
            long runTimeMilliSec = new Date().getTime() - startTime;
            
            long cpuOp =   myFarmer.getOperation()  / runTimeMilliSec;
            long ioRead =  myFarmer.getReadBytes()  / runTimeMilliSec;
            long ioWrite = myFarmer.getWriteBytes() / runTimeMilliSec;
            
            print(wCount, runTimeMilliSec, cpuOp, ioRead, ioWrite);
            
        }
    }
    
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {
        java.awt.GridBagConstraints gridBagConstraints;

        btnStart = new javax.swing.JButton();
        pnlConfig = new javax.swing.JPanel();
        lblTesterClass = new javax.swing.JLabel();
        txtMinThreadCount = new javax.swing.JTextField();
        lblMinThreadCount = new javax.swing.JLabel();
        txtMaxThreadCount = new javax.swing.JTextField();
        lblMaxThreadCount = new javax.swing.JLabel();
        txtIncrement = new javax.swing.JTextField();
        lblIncrement = new javax.swing.JLabel();
        cmbTesterClass = new javax.swing.JComboBox();
        pnlLast = new javax.swing.JPanel();
        lblThreadCount = new javax.swing.JLabel();
        prbThreadCount = new javax.swing.JProgressBar();
        lblOperation = new javax.swing.JLabel();
        prbOperation = new javax.swing.JProgressBar();
        lblRead = new javax.swing.JLabel();
        prbRead = new javax.swing.JProgressBar();
        lblWrite = new javax.swing.JLabel();
        prbWrite = new javax.swing.JProgressBar();
        prbRunTimeSec = new javax.swing.JProgressBar();
        lblRunTimeSec = new javax.swing.JLabel();
        pnlBestWorst = new javax.swing.JPanel();
        lblMaxOperation = new javax.swing.JLabel();
        lblMaxOperationView = new javax.swing.JLabel();
        lblMinOperation = new javax.swing.JLabel();
        lblMinOperationView = new javax.swing.JLabel();
        lblMaxIORead = new javax.swing.JLabel();
        lblMaxIOReadView = new javax.swing.JLabel();
        lblMinIORead = new javax.swing.JLabel();
        lblMinIOReadView = new javax.swing.JLabel();
        lblMaxIOWrite = new javax.swing.JLabel();
        lblMaxIOWriteView = new javax.swing.JLabel();
        lblMinIOWrite = new javax.swing.JLabel();
        lblMinIOWriteView = new javax.swing.JLabel();
        lblMaxRunTimeSec = new javax.swing.JLabel();
        lblMinRunTimeSec = new javax.swing.JLabel();
        lblMaxRunTimeSecView = new javax.swing.JLabel();
        lblMinRunTimeSecView = new javax.swing.JLabel();
        chbGarbageCollector = new javax.swing.JCheckBox();

        getContentPane().setLayout(null);

        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
        setTitle("ThreadMark");
        setResizable(false);
        btnStart.setText("Start");
        btnStart.setMaximumSize(new java.awt.Dimension(100, 25));
        btnStart.setMinimumSize(new java.awt.Dimension(100, 25));
        btnStart.setPreferredSize(new java.awt.Dimension(100, 25));
        btnStart.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnStartActionPerformed(evt);
            }
        });

        getContentPane().add(btnStart);
        btnStart.setBounds(400, 290, 240, 36);

        pnlConfig.setLayout(new java.awt.GridBagLayout());

        pnlConfig.setBorder(javax.swing.BorderFactory.createTitledBorder("Configuration"));
        lblTesterClass.setText("Test");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlConfig.add(lblTesterClass, gridBagConstraints);

        txtMinThreadCount.setText("1");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlConfig.add(txtMinThreadCount, gridBagConstraints);

        lblMinThreadCount.setText("Min Thread Count");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlConfig.add(lblMinThreadCount, gridBagConstraints);

        txtMaxThreadCount.setText("10");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlConfig.add(txtMaxThreadCount, gridBagConstraints);

        lblMaxThreadCount.setText("Max Thread Count");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlConfig.add(lblMaxThreadCount, gridBagConstraints);

        txtIncrement.setText("1");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlConfig.add(txtIncrement, gridBagConstraints);

        lblIncrement.setText("Increment");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlConfig.add(lblIncrement, gridBagConstraints);

        cmbTesterClass.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Find Primes (CPU)", "Multiple File (I/O)", "Code File (CPU & I/O)" }));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlConfig.add(cmbTesterClass, gridBagConstraints);

        getContentPane().add(pnlConfig);
        pnlConfig.setBounds(10, 10, 380, 150);

        pnlLast.setLayout(new java.awt.GridBagLayout());

        pnlLast.setBorder(javax.swing.BorderFactory.createTitledBorder("Last Results"));
        lblThreadCount.setText("Thread Count");
        lblThreadCount.setMinimumSize(new java.awt.Dimension(150, 0));
        lblThreadCount.setPreferredSize(new java.awt.Dimension(150, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlLast.add(lblThreadCount, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlLast.add(prbThreadCount, gridBagConstraints);

        lblOperation.setText("Operation");
        lblOperation.setMinimumSize(new java.awt.Dimension(150, 0));
        lblOperation.setPreferredSize(new java.awt.Dimension(150, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlLast.add(lblOperation, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlLast.add(prbOperation, gridBagConstraints);

        lblRead.setText("Read");
        lblRead.setMinimumSize(new java.awt.Dimension(150, 0));
        lblRead.setPreferredSize(new java.awt.Dimension(150, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlLast.add(lblRead, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlLast.add(prbRead, gridBagConstraints);

        lblWrite.setText("Write");
        lblWrite.setMinimumSize(new java.awt.Dimension(150, 0));
        lblWrite.setPreferredSize(new java.awt.Dimension(150, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlLast.add(lblWrite, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlLast.add(prbWrite, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlLast.add(prbRunTimeSec, gridBagConstraints);

        lblRunTimeSec.setText("Run Time");
        lblRunTimeSec.setMinimumSize(new java.awt.Dimension(150, 0));
        lblRunTimeSec.setPreferredSize(new java.awt.Dimension(150, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlLast.add(lblRunTimeSec, gridBagConstraints);

        getContentPane().add(pnlLast);
        pnlLast.setBounds(10, 170, 380, 160);

        pnlBestWorst.setLayout(new java.awt.GridBagLayout());

        pnlBestWorst.setBorder(javax.swing.BorderFactory.createTitledBorder("Best & Worst Results [Thread Count]"));
        lblMaxOperation.setText("Max Operation");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlBestWorst.add(lblMaxOperation, gridBagConstraints);

        lblMaxOperationView.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
        lblMaxOperationView.setMinimumSize(new java.awt.Dimension(110, 19));
        lblMaxOperationView.setPreferredSize(new java.awt.Dimension(110, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlBestWorst.add(lblMaxOperationView, gridBagConstraints);

        lblMinOperation.setText("Min Operation");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlBestWorst.add(lblMinOperation, gridBagConstraints);

        lblMinOperationView.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
        lblMinOperationView.setMinimumSize(new java.awt.Dimension(110, 19));
        lblMinOperationView.setPreferredSize(new java.awt.Dimension(110, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlBestWorst.add(lblMinOperationView, gridBagConstraints);

        lblMaxIORead.setText("Max Read");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlBestWorst.add(lblMaxIORead, gridBagConstraints);

        lblMaxIOReadView.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
        lblMaxIOReadView.setMinimumSize(new java.awt.Dimension(110, 19));
        lblMaxIOReadView.setPreferredSize(new java.awt.Dimension(110, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlBestWorst.add(lblMaxIOReadView, gridBagConstraints);

        lblMinIORead.setText("Min Read");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlBestWorst.add(lblMinIORead, gridBagConstraints);

        lblMinIOReadView.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
        lblMinIOReadView.setMinimumSize(new java.awt.Dimension(110, 19));
        lblMinIOReadView.setPreferredSize(new java.awt.Dimension(110, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlBestWorst.add(lblMinIOReadView, gridBagConstraints);

        lblMaxIOWrite.setText("Max Write");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlBestWorst.add(lblMaxIOWrite, gridBagConstraints);

        lblMaxIOWriteView.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
        lblMaxIOWriteView.setMinimumSize(new java.awt.Dimension(110, 19));
        lblMaxIOWriteView.setPreferredSize(new java.awt.Dimension(110, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlBestWorst.add(lblMaxIOWriteView, gridBagConstraints);

        lblMinIOWrite.setText("Min Write");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 7;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlBestWorst.add(lblMinIOWrite, gridBagConstraints);

        lblMinIOWriteView.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
        lblMinIOWriteView.setMinimumSize(new java.awt.Dimension(110, 19));
        lblMinIOWriteView.setPreferredSize(new java.awt.Dimension(110, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 7;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlBestWorst.add(lblMinIOWriteView, gridBagConstraints);

        lblMaxRunTimeSec.setText("Max Run Time");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlBestWorst.add(lblMaxRunTimeSec, gridBagConstraints);

        lblMinRunTimeSec.setText("Min Run Time");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlBestWorst.add(lblMinRunTimeSec, gridBagConstraints);

        lblMaxRunTimeSecView.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
        lblMaxRunTimeSecView.setMinimumSize(new java.awt.Dimension(110, 19));
        lblMaxRunTimeSecView.setPreferredSize(new java.awt.Dimension(110, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlBestWorst.add(lblMaxRunTimeSecView, gridBagConstraints);

        lblMinRunTimeSecView.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
        lblMinRunTimeSecView.setMinimumSize(new java.awt.Dimension(110, 19));
        lblMinRunTimeSecView.setPreferredSize(new java.awt.Dimension(110, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        pnlBestWorst.add(lblMinRunTimeSecView, gridBagConstraints);

        getContentPane().add(pnlBestWorst);
        pnlBestWorst.setBounds(400, 10, 240, 240);

        chbGarbageCollector.setText("Run GC Before Every Test");
        chbGarbageCollector.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        chbGarbageCollector.setMargin(new java.awt.Insets(0, 0, 0, 0));
        getContentPane().add(chbGarbageCollector);
        chbGarbageCollector.setBounds(410, 255, 230, 30);

    }// </editor-fold>//GEN-END:initComponents
    
    private void btnStartActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnStartActionPerformed
        start(cmbTesterClass.getSelectedItem().toString());
    }//GEN-LAST:event_btnStartActionPerformed
                    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton btnStart;
    private javax.swing.JCheckBox chbGarbageCollector;
    private javax.swing.JComboBox cmbTesterClass;
    private javax.swing.JLabel lblIncrement;
    private javax.swing.JLabel lblMaxIORead;
    private javax.swing.JLabel lblMaxIOReadView;
    private javax.swing.JLabel lblMaxIOWrite;
    private javax.swing.JLabel lblMaxIOWriteView;
    private javax.swing.JLabel lblMaxOperation;
    private javax.swing.JLabel lblMaxOperationView;
    private javax.swing.JLabel lblMaxRunTimeSec;
    private javax.swing.JLabel lblMaxRunTimeSecView;
    private javax.swing.JLabel lblMaxThreadCount;
    private javax.swing.JLabel lblMinIORead;
    private javax.swing.JLabel lblMinIOReadView;
    private javax.swing.JLabel lblMinIOWrite;
    private javax.swing.JLabel lblMinIOWriteView;
    private javax.swing.JLabel lblMinOperation;
    private javax.swing.JLabel lblMinOperationView;
    private javax.swing.JLabel lblMinRunTimeSec;
    private javax.swing.JLabel lblMinRunTimeSecView;
    private javax.swing.JLabel lblMinThreadCount;
    private javax.swing.JLabel lblOperation;
    private javax.swing.JLabel lblRead;
    private javax.swing.JLabel lblRunTimeSec;
    private javax.swing.JLabel lblTesterClass;
    private javax.swing.JLabel lblThreadCount;
    private javax.swing.JLabel lblWrite;
    private javax.swing.JPanel pnlBestWorst;
    private javax.swing.JPanel pnlConfig;
    private javax.swing.JPanel pnlLast;
    private javax.swing.JProgressBar prbOperation;
    private javax.swing.JProgressBar prbRead;
    private javax.swing.JProgressBar prbRunTimeSec;
    private javax.swing.JProgressBar prbThreadCount;
    private javax.swing.JProgressBar prbWrite;
    private javax.swing.JTextField txtIncrement;
    private javax.swing.JTextField txtMaxThreadCount;
    private javax.swing.JTextField txtMinThreadCount;
    // End of variables declaration//GEN-END:variables
    
}
